import { EventDispatcher, Quaternion, Vector3 } from "three";
import { Settings } from "../settings/Settings.js";
import { Disposable } from "./Disposable.js";
import { Updatable } from "./Updatable.js";
/**
 * Spatial controls for 3D translation and rotation.
 *
 * This class emits events of type {@link EVENT_UPDATE} when the position or quaternion is changed.
 *
 * @group Core
 */
export declare class SpatialControls extends EventDispatcher implements Disposable, EventListenerObject, Updatable {
    /**
     * Triggers when the position or quaternion is changed.
     *
     * @event
     */
    static readonly EVENT_UPDATE = "update";
    /**
     * @see {@link domElement}
     */
    private _domElement;
    /**
     * @see {@link position}
     */
    private _position;
    /**
     * @see {@link quaternion}
     */
    private _quaternion;
    /**
     * @see {@link target}
     */
    private _target;
    /**
     * The previous position.
     */
    private previousPosition;
    /**
     * The previous quaternion.
     */
    private previousQuaternion;
    /**
     * The previous target.
     */
    private previousTarget;
    /**
     * A rotation manager.
     */
    private rotationManager;
    /**
     * A translation manager.
     */
    private translationManager;
    /**
     * A map that links actions to specific strategies.
     */
    private strategies;
    /**
     * Indicates whether the user is currently holding the pointer button down.
     */
    private dragging;
    /**
     * @see {@link enabled}
     */
    private _enabled;
    /**
     * The control settings.
     */
    readonly settings: Settings;
    /**
     * Constructs new controls.
     *
     * @param position - A position.
     * @param quaternion - A quaternion.
     * @param domElement - A DOM element. Serves as the primary event target.
     */
    constructor(position?: Vector3, quaternion?: Quaternion, domElement?: HTMLElement | null);
    /**
     * A DOM element. Acts as the primary event target.
     */
    get domElement(): HTMLElement | null;
    set domElement(domElement: HTMLElement | null);
    /**
     * The position.
     */
    get position(): Vector3;
    set position(value: Vector3);
    /**
     * The quaternion.
     */
    get quaternion(): Quaternion;
    set quaternion(value: Quaternion);
    /**
     * The target.
     */
    get target(): Vector3;
    set target(value: Vector3);
    /**
     * Looks at the given point.
     *
     * @param x - The X-coordinate, or a point.
     * @param y - The Y-coordinate.
     * @param z - The Z-coordinate.
     * @return This instance.
     */
    lookAt(x: number | Vector3, y?: number, z?: number): SpatialControls;
    /**
     * Returns the current view direction.
     *
     * @param view - A vector to store the direction in.
     * @return The normalized view direction.
     */
    getViewDirection(view: Vector3): Vector3;
    /**
     * Indicates whether the controls are enabled.
     *
     * Event listeners will be registered or unregistered depending on this flag.
     */
    get enabled(): boolean;
    set enabled(value: boolean);
    /**
     * Copies the given controls.
     *
     * @param controls - A controls instance.
     * @return This instance.
     */
    copy(controls: SpatialControls): SpatialControls;
    /**
     * Clones this instance.
     *
     * @return The cloned controls.
     */
    clone(): SpatialControls;
    /**
     * Locks or unlocks the pointer.
     *
     * @param locked - Whether the pointer should be locked.
     */
    setPointerLocked(locked?: boolean): void;
    /**
     * Enables or disables the rotation mode.
     *
     * @param pressed - Whether the rotation mode should be activated.
     */
    setRotationEnabled(enabled: boolean): void;
    /**
     * Handles pointer move events.
     *
     * @param event - A pointer event.
     */
    private handlePointerMoveEvent;
    /**
     * Handles pointer button events.
     *
     * @param event - A pointer event.
     * @param pressed - Whether the pointer button has been pressed down.
     */
    private handlePointerButtonEvent;
    /**
     * Handles pointer cancel and leave events.
     *
     * @param event - A pointer event.
     */
    private handlePointerCancelEvent;
    /**
     * Handles wheel events.
     *
     * @param event - A wheel event.
     */
    private handleWheelEvent;
    /**
     * Handles keyboard events.
     *
     * @param event - A keyboard event.
     * @param pressed - Whether the key has been pressed down.
     */
    private handleKeyboardEvent;
    /**
     * Enables or disables controls based on the pointer lock state.
     */
    private handlePointerLockEvent;
    /**
     * Cancels active interactions on visibility loss.
     */
    private handleVisibilityChangeEvent;
    /**
     * Reacts to setting changes.
     *
     * @param event - An event.
     */
    private onSettingsChanged;
    /**
     * Synchronizes the internal state with external changes.
     */
    private synchronize;
    handleEvent(event: Event): void;
    update(timestamp: number): void;
    dispose(): void;
}
